import { AxiosResponse } from 'axios'
import {
    ResultOutputCompanyDrawOutput,
    CompanyDrawInput,
    ProjectPriceSetInput,
    pageInputProjectPriceSetPageInput,
    ResultOutputPageOutputPriceGetPageOutput,
    PageInputTenantPriceGetPageInput,
    ResultOutputPageOutputTenantPriceGetPageOutput,
    TenantDrawSetInput,
    DrawInfoInput
} from './data-contracts'
import { ContentType, HttpClient, RequestParams } from './http-client'

export class ProjectPriceApi<SecurityDataType = unknown> extends HttpClient<SecurityDataType>{
    /**
   * No description
   *
   * @tags role
   * @name Get
   * @summary 查询公司抽成信息
   * @request GET:/api/admin/project-price/get-company-draw
   * @secure
   */
    getCompanyDraw = (
        query?: {            
        },
        params: RequestParams = {}
    ) =>
        this.request<ResultOutputCompanyDrawOutput, any>({
            path: `/api/admin/project-price/get-company-draw`,
            method: 'GET',
            query: query,
            secure: true,
            format: 'json',
            ...params,
        })
    /**
   * No description
   *
   * @tags org
   * @name Update
   * @summary 修改公司抽成比例
   * @request Post:/api/admin/project-price/edit-company-draw
   * @secure
   */
    updateCompany = (data: CompanyDrawInput, params: RequestParams = {}) =>
        this.request<AxiosResponse, any>({
            path: `/api/admin/project-price/edit-company-draw`,
            method: 'Post',
            body: data,
            secure: true,
            type: ContentType.Json,
            ...params,
        })
    /**
   * No description
   *
   * @tags projectprice
   * @name GetPage
   * @summary 查询项目价格分页
   * @request POST:/api/admin/project-price/get-project-page
   * @secure
   */
    getPricePage = (data: pageInputProjectPriceSetPageInput, params: RequestParams = {}) =>
        this.request<ResultOutputPageOutputPriceGetPageOutput, any>({
            path: `/api/admin/project-price/get-project-page`,
            method: 'Post',
            body: data,
            secure: true,
            type: ContentType.Json,
            format: 'json',
            ...params,
        })   
    /**
  * No description
  *
  * @tags org
  * @name Update
  * @summary 修改公司抽成比例
  * @request Post:/api/admin/project-price/set-project-price
  * @secure
  */
    updateProjectPrice = (data: ProjectPriceSetInput, params: RequestParams = {}) =>
        this.request<AxiosResponse, any>({
            path: `/api/admin/project-price/set-project-price`,
            method: 'Post',
            body: data,
            secure: true,
            type: ContentType.Json,
            ...params,
        })
    /**
   * No description
   *
   * @tags projectprice
   * @name GetPage
   * @summary 查询平台单独设价分页
   * @request POST:/api/admin/project-price/get-tenant-draw-page
   * @secure
   */
    getTenantPage = (data: PageInputTenantPriceGetPageInput, params: RequestParams = {}) =>
        this.request<ResultOutputPageOutputTenantPriceGetPageOutput, any>({
            path: `/api/admin/project-price/get-tenant-draw-page`,
            method: 'Post',
            body: data,
            secure: true,
            type: ContentType.Json,
            format: 'json',
            ...params,
        })
    /**
  * No description
  *
  * @tags org
  * @name Update
  * @summary 修改平台单独设置抽成比例
  * @request Post:/api/admin/project-price/set-tenant-draw
  * @secure
  */
    updateTenantPriceSet = (data: TenantDrawSetInput, params: RequestParams = {}) =>
        this.request<AxiosResponse, any>({
            path: `/api/admin/project-price/set-tenant-draw`,
            method: 'Post',
            body: data,
            secure: true,
            type: ContentType.Json,
            ...params,
        })
    /**
* No description
*
* @tags project-price
* @name get-draw-info
* @summary 下次生效信息
* @request Post:/api/admin/project-price/get-draw-info
* @secure
*/
    GetDrawInfo = (data: DrawInfoInput, params: RequestParams = {}) =>
        this.request<AxiosResponse, any>({
            path: `/api/admin/project-price/get-draw-info`,
            method: 'Post',
            body: data,
            secure: true,
            type: ContentType.Json,
            ...params,
        })
}